import express from 'express';
import logger from 'morgan';
import Bourne from 'bourne';
import path from 'path';
import graphqlHTTP from 'express-graphql';
import {buildSchema} from 'graphql';
import {importSchema} from 'graphql-import';
import {connectionFromArray} from 'graphql-relay';

const app = express();
const recipes = new Bourne('db/recipes.json');

app.use(logger('dev'));
app.use(express.static('public'));

// Construct a schema, using GraphQL schema language
const schemaDef = importSchema(path.resolve('schema.graphql'));
const schema = buildSchema(schemaDef);

// The root provides a resolver function for each API endpoint
const root = {
  // Queries
  recipes(args) {
    let conn = {};
    recipes.find((err, results) => {
      conn = connectionFromArray(results, args);
    });
    return conn;
  },
  // Mutations
  changeRecipeRate: ({input}) => {
    let recipe = {};
    recipes.findOne({
      id: input.id
    }, (err, result) => {
      recipe = {
        ...result,
        rating: input.rating
      };
      recipes.update({id: recipe.id}, recipe);
    });
    return recipe;
  }
};

app.use('/graphql', graphqlHTTP({
  schema,
  rootValue: root,
  graphiql: true
}));

app.listen(3000, () => console.log(`GraphQL application running at 'http://localhost:3000'`));
