import React from 'react'
import IngredientsList from './ingredients-list'
import Instructions from './instructions'
import StarRating from './star-rating';
import Summary from './summary';
import {graphql, createFragmentContainer} from 'react-relay';
import changeRecipeRate from '../mutations/change-recipe-rate';
import environment from '../environment';

const Recipe = ({recipe}) => {
  const onRate = rating => {
    changeRecipeRate(environment, rating, recipe.id);
  }
  const {name, ingredients, steps, rating} = recipe;
  return (
    <section id={recipe.name.toLowerCase().replace(/\s/g, '-')}>
      <h2>{recipe.name}</h2>
      <IngredientsList list={ingredients}/>
      <Instructions title="Cooking Instructions" steps={steps}/>
      <StarRating starsSelected={rating} onRate={onRate}/>
      <Summary ingredientsCount={ingredients.length}
        stepsCount={steps.length}/>
    </section>
  )
}

export default createFragmentContainer(
  Recipe,
  graphql`
    fragment recipe_recipe on Recipe {
      id
      name
      ingredients {
        ...ingredient_item
      }
      steps
      rating
    }
  `
);
